//
//  ViewController.swift
//  Calculator
//
//  Created by David Reed on 2/1/19.
//  Copyright © 2019 David Reed. All rights reserved.
//

import UIKit

class ViewController: UIViewController {
    var model = CalculatorModel()  // model for calculator operation
    var freshStart = true          // true if about to enter a new number

    @IBOutlet weak var displayLabel: UILabel!
    
    // Action associated with clicking the Clear button.
    @IBAction func clearClicked(_ sender: UIButton) {
        displayLabel.text = "0"
        model.clear()
    }
    
    // Action associated with clicking the +/- button.
    @IBAction func negateClicked(_ sender: UIButton) {
        displayLabel.text = numToString(-Double(displayLabel.text!)!)
    }
 
    // Action associated with clicking the % button.
    @IBAction func percentClicked(_ sender: UIButton) {
        displayLabel.text = numToString(0.01*Double(displayLabel.text!)!)
    }
    
    // Action associated with clicking a digit or '.' button.
    @IBAction func numberClicked(_ sender: UIButton) {
        if let labelValue = displayLabel.text {
            if let buttonValue = sender.titleLabel!.text {
                if labelValue == "0" || freshStart {
                     displayLabel.text = ""
                }
                freshStart = false

                if buttonValue == "." {
                    if !displayLabel.text!.contains(".") {
                        displayLabel.text = displayLabel.text! + "."
                    }
                }
                else {
                    displayLabel.text = displayLabel.text! + buttonValue
                }
            }
        }
    }
    
    // Action associated with clicking any operator button.
    @IBAction func operatorClicked(_ sender: UIButton) {
        if let labelValue = displayLabel.text {
            if let buttonValue = sender.titleLabel!.text {
                model.apply(op: buttonValue, with: Double(labelValue)!)
                displayLabel.text = numToString(model.currentValue)
                freshStart = true
            }
        }
    }
}

/////////////////////////////////////////////////////////////////////////

// Helper function that converts a Double into a String,
//   excludes .0 if it is a whole number
func numToString(_ val: Double) -> String {
    if val.truncatingRemainder(dividingBy: 1) == 0 {
        return String(Int(val))
    }
    else {
        return String(val)
    }
}
